class Greetings:
    def __init__(self, name = None):
        """
        Initialises a greetings object with the name of the person
        """
        if name:
            self.name = name
        else:
           self.name = input("Hello, please enter your name: ")
        

    
    # @staticmethod
    def hello(self):
        print(f"Hello {self.name}!")

    # @staticmethod
    def goodbye(self):
        print(f"See you {self.name}!")

    def reverse_name(self):
        self.name = self.name.lower()[::-1].capitalize()


if __name__ == "__main__":
    # a = Greetings()
    # a.hello()
    a = Greetings()
    a.hello()
    a.reverse_name()
    a.hello()
    print(a.name)

    Greetings("Karl").hello()


import unittest

import llutils.Greetings as Greetings

class Test(unittest.TestCase):
    def test_reverse_name(self):
        greet = Greetings("Lukas")
        self.assertEqual(greet.name, "Lukas")
        greet.reverse_name()
        self.assertEqual(greet.name, "Sakul")

if __name__ == "__main__":
    Test().test_reverse_name()